@@ -6,8 +6,9 @@ try:
 except ImportError:
     pass
 
-import ttspod.app
+import app
+
 
 def main():
     """main python entrypoint"""
-    ttspod.app.main()
+    app.main()
