@@ -9,12 +9,12 @@ except ImportError:
 # standard modules
 try:
     from anyascii import anyascii
+    from warnings import simplefilter
     import os
     import re
     from time import time
     import unicodedata
     import uuid
-    import warnings
 except ImportError as e:
     print(
         f'Failed to import required module: {e}\n'
@@ -22,38 +22,12 @@ except ImportError as e:
     exit()
 
 # TTSPod modules
-from ttspod.logger import Logger
-from ttspod.speech.paid import Paid
+from logger import Logger
+from util import check_engines
 
-# optional generator modules
-ENGINES = {}
-# pylint: disable=unused-import
-# pylint: disable=ungrouped-imports
-try:
-    from openai import OpenAI
-    # necessary for OpenAI TTS streaming
-    warnings.filterwarnings("ignore", category=DeprecationWarning)
-    ENGINES['openai'] = True
-except ImportError:
-    pass
-try:
-    from elevenlabs.client import ElevenLabs
-    from elevenlabs import save
-    ENGINES['eleven'] = True
-except ImportError:
-    pass
-try:
-    from ttspod.speech.whisper import Whisper
-    ENGINES['whisper'] = True
-except ImportError:
-    pass
-try:
-    from ttspod.speech.coqui import Coqui
-    ENGINES['coqui'] = True
-except ImportError:
-    pass
-# pylint: enable=unused-import
-# pylint: enable=ungrouped-imports
+simplefilter(action='ignore', category=FutureWarning)
+
+ENGINES = check_engines()
 
 
 class Speech(object):
@@ -67,18 +41,26 @@ class Speech(object):
         self.config = config
         self.config.nltk = False
         self.final_path = config.final_path
+        # pylint: disable=import-outside-toplevel
         match self.config.engine.lower():
             case "openai" if "openai" in ENGINES:
+                from paid import Paid
                 self.tts = Paid(config=self.config, log=self.log)
             case "eleven" if "eleven" in ENGINES:
+                from paid import Paid
                 self.tts = Paid(config=self.config, log=self.log)
             case "whisper" if "whisper" in ENGINES:
+                from whisper import Whisper
                 self.tts = Whisper(config=self.config, log=self.log)
             case "coqui" if "coqui" in ENGINES:
+                from coqui import Coqui
                 self.tts = Coqui(config=self.config, log=self.log)
+            case "f5" if "f5" in ENGINES:
+                from f5 import F5
+                self.tts = F5(config=self.config, log=self.log)
             case _:
                 raise ValueError('TTS engine not configured')
-
+        # pylint: enable=import-outside-toplevel
     def slugify(self, value):
         """convert an arbitrary string to a valid filename"""
         value = str(value)
@@ -87,10 +69,13 @@ class Speech(object):
         value = re.sub(r'[^\w\s-]', '', value.lower())
         return re.sub(r'[-\s]+', '-', value).strip('-_')
 
-    def speechify(self, title="No Title Available", raw_text=""):
+    def speechify(self, title="No Title Available", raw_text="", overwrite=True):
         """workhorse TTS function"""
         clean_title = self.slugify(title)
         out_file = os.path.join(self.config.final_path, f'{clean_title}.mp3')
+        if os.path.isfile(out_file) and not overwrite:
+            self.log.write(f'skipping {out_file} because it already exists')
+            return out_file
         text = anyascii(raw_text)
         text = re.sub('^.{,8}$', '', text, flags=re.MULTILINE)
         text = re.sub('^.{,8}$', '', text, flags=re.MULTILINE)
@@ -106,7 +91,7 @@ class Speech(object):
             return
         self.log.write(f'starting TTS conversion to {out_file}')
         if title != "No Title Available":
-            text = title + "\n\n" + text
+            text = title.strip() + ".\n\n" + text.strip()
         self.log.write(self.tts.convert(text=text, output_file=out_file))
         elapsed = round(time() - start_time)
         self.log.write(
